# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:38:04+00:00

from __future__ import annotations

from pydantic import BaseModel, Extra


class Websocket(BaseModel):
    class Config:
        extra = Extra.forbid

    subscription: list[str] | None = None
    ignore: list[str] | None = None
    full: bool | None = None
