# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:28:39+00:00

from __future__ import annotations

from enum import Enum

from pydantic import BaseModel, Extra


class Bucket(Enum):
    default = 'default'
    user = 'user'


class Couchbase(BaseModel):
    class Config:
        extra = Extra.forbid

    bucket:  Bucket | None = None
    id: list[str] | None = None
    metadata: bool | None = None
