# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:37:40+00:00

from __future__ import annotations

from pydantic import BaseModel


class TransferUser(BaseModel):
    username: str
    password: str | None = None
    documents: list[str] | None = None
    tables: list[str] | None = None
