# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:26:45+00:00

from __future__ import annotations

import uuid
from pydantic import BaseModel, Extra, constr


class Meta(BaseModel):
    id: uuid.UUID | None = None
    type: str | None = None
    version: constr(regex=r'(\d+)\.(\d+)') | None = None
    trace: str | None = None
    accept_manufacturer_as_owner: bool | None = None
    accept_test_mode: bool | None = None


class AddNotOwned(BaseModel):
    class Config:
        extra = Extra.forbid

    meta:  Meta | None = None
