# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:30:41+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, conint


class Extsync(BaseModel):
    timeout: Optional[conint(ge=1, le=60)] = None
