# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:35:31+00:00

from __future__ import annotations

from enum import Enum
from pydantic import BaseModel, Extra, constr


class Request(Enum):
    delete_user = 'delete_user'
    recovery_password = 'recovery_password'
    change_password = 'change_password'
    confirm_new_username = 'confirm_new_username'
    confirm_registration = 'confirm_registration'
    confirm_deletion_user = 'confirm_deletion_user'
    verify_email = 'verify_email'
    confirm_email = 'confirm_email'
    verify_changed_email = 'verify_changed_email'
    confirm_changed_email = 'confirm_changed_email'
    verify_phone_number = 'verify_phone_number'
    confirm_phone_number = 'confirm_phone_number'


class Register(BaseModel):
    class Config:
        extra = Extra.forbid

    key: constr(regex=r'[0-9a-fA-F]{64}|[0-9]{6}') | None = None
    request:  Request | None = None
