# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:26:39+00:00

from __future__ import annotations

import uuid
from pydantic import BaseModel, Extra, conint


class Acl(BaseModel):
    class Config:
        extra = Extra.forbid

    id: list[uuid.UUID] | None = None
    expand: conint(ge=0, multiple_of=1) | None = None
    propagate: bool | None = None
    verbose: bool | list[str] | None = None
    prev_notification: uuid.UUID | None = None
