# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:28:42+00:00

from __future__ import annotations

import datetime
from enum import Enum

from pydantic import BaseModel, Extra


class Type(Enum):
    user = 'user'
    network = 'network'
    number_networks = 'number_networks'
    mda = 'mda'
    sms = 'sms'


class Counter(BaseModel):
    class Config:
        extra = Extra.forbid

    start: datetime.datetime | None = None
    end: datetime.datetime | None = None
    csv: bool | None = None
    type:  Type | None = None
    subtype: str | None = None
    user_id: list[str] | None = None
    network_id: list[str] | None = None
