# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:35:47+00:00

from __future__ import annotations

from enum import Enum
from typing import Any

from pydantic import BaseModel


class Jsonrpc(Enum):
    field_2_1 = '2.1'


class RpcRequest(BaseModel):
    jsonrpc: Jsonrpc
    method: str
    id: str | float | None = None
    params: list[Any] | dict[str, Any] | None = None
