# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:36:16+00:00

from __future__ import annotations

import uuid
from pydantic import BaseModel, Extra, constr


class Credential(BaseModel):
    class Config:
        extra = Extra.forbid

    access_token: str | None = None
    id_token: str | None = None
    secret: str | None = None


class MetaItem(BaseModel):
    class Config:
        extra = Extra.allow

    id: uuid.UUID | None = None
    trace: str | None = None
    redirect: constr(regex=r'^[0-9a-zA-Z_-]+$', min_length=1, max_length=200) | None = None
    icon: str | None = None
    tag: list[constr(min_length=2, max_length=20)] | None = None
    tag_by_user: list[constr(min_length=2, max_length=20)] | None = None
    name_by_user: constr(max_length=100) | None = None


class Session(BaseModel):
    class Config:
        extra = Extra.allow

    username: str | None = None
    password: str | None = None
    remember_me: bool | None = None
    system: str | None = None
    captcha: str | None = None
    provider: str | None = None
    installation: uuid.UUID | None = None
    firebase_token: str | None = None
    credentials:  Credential | None = None
    meta:  MetaItem | None = None
    admin: bool | None = None
    dashboard: str | None = None
    test_mode: bool | None = None
    theme: str | None = None
