# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:33:21+00:00

from __future__ import annotations

import uuid

from enum import Enum
from typing import Any
from pydantic import BaseModel, Extra, Field, constr


class Read(Enum):
    read = 'read'
    unread = 'unread'
    accepted = 'accepted'
    denied = 'denied'
    deleted = 'deleted'


class Base(BaseModel):
    class Config:
        extra = Extra.allow

    to: uuid.UUID | None = None
    ids: list[uuid.UUID] | None = None


class Meta(BaseModel):
    class Config:
        extra = Extra.allow

    id: uuid.UUID | None = None
    trace: str | None = None
    redirect: constr(regex=r'^[0-9a-zA-Z_-]+$', min_length=1, max_length=200) | None = None
    icon: str | None = None
    tag: list[constr(min_length=2, max_length=20)] | None = None
    tag_by_user: list[constr(min_length=2, max_length=20)] | None = None
    name_by_user: constr(max_length=100) | None = None


class Notification(BaseModel):
    class Config:
        extra = Extra.allow

    read:  Read | None = None
    custom: dict[str, Any] | None = None
    base:  Base | None = None
    meta: Meta | None = Field(None, title='meta-2.1')
