# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:35:37+00:00

from __future__ import annotations

from enum import Enum
from typing import Any, Optional, Union

from pydantic import BaseModel


class Jsonrpc(Enum):
    field_2_1 = '2.1'


class Error(BaseModel):
    code: int
    message: str
    data: Any | None = None


class RpcError(BaseModel):
    id: str | int | None
    jsonrpc: Jsonrpc
    error: Error
