# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:37:37+00:00

from __future__ import annotations

from pydantic import BaseModel


class TransferTranslation(BaseModel):
    pass
