# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:30:31+00:00

from __future__ import annotations

import uuid
import datetime
from enum import Enum
from typing import Any, Literal

from pydantic import BaseModel, Extra, Field, constr


class Assigned(Enum):
    unassigned = 'unassigned'
    admin = 'admin'


class WarningItem(BaseModel):
    message: str | None = None
    data: dict[str, Any] | None = None
    code: int | None = None


class Meta(BaseModel):
    class Config:
        extra = Extra.forbid

    id: uuid.UUID | None = None
    type: str | None = None
    version: constr(regex=r'(\d+)\.(\d+)') | None = None
    manufacturer: uuid.UUID | Assigned | None = None
    owner: uuid.UUID | Assigned | None = None
    created: datetime.datetime | Literal['not_available'] | None = None
    updated: datetime.datetime | Literal['not_available'] | None = None
    changed: datetime.datetime | Literal['not_available'] | None = None
    application: uuid.UUID | None = None
    revision: int | None = None
    trace: str | None = None
    oem: str | None = None
    deprecated: bool | None = None
    redirect: constr(regex=r'^[0-9a-zA-Z_-]+$', min_length=1, max_length=200) | None = None
    size: int | None = None
    path: str | None = None
    parent: uuid.UUID | None = None
    error: dict[str, Any] | None = None
    icon: str | None = None
    tag: list[constr(min_length=2, max_length=20)] | None = None
    tag_by_user: list[constr(min_length=2, max_length=20)] | None = None
    name_by_user: constr(max_length=100) | None = None
    warning: list[WarningItem] | None = None
    parent_name: dict[str, Any] | None = None
    read_only: bool | None = None
    original_id: uuid.UUID | None = None
    alert: list[uuid.UUID] | None = None
    contract: list[uuid.UUID] | None = None


class FailedItem(BaseModel):
    id: uuid.UUID | None = None
    last_update: datetime.datetime | None = None


class ExpectedState(BaseModel):
    class Config:
        extra = Extra.forbid

    meta: Meta | None = Field(None, title='meta-2.1')
    name: str | None = None
    application: uuid.UUID | None = None
    product: str | None = None
    network_name: str | None = None
    device_name: str | None = None
    value_type: str | None = None
    manufacturer: uuid.UUID | None = None
    expected_update: int | None = None
    check_if_network_online: bool | None = None
    check_if_points_are_finished: bool | None = None
    number_failed: int | None = None
    number_states: int | None = None
    failed: list[FailedItem] | None = None
