# generated by datamodel-codegen:
#   filename:  <stdin>
#   timestamp: 2023-02-17T08:29:53+00:00

from __future__ import annotations

from pydantic import BaseModel, Extra


class Download(BaseModel):
    pass

    class Config:
        extra = Extra.forbid
